@@ -5,9 +5,7 @@ from trytond.pool import Pool
 
 __all__ = ['register']
 
-from . import web
-from . import product
-from . import sale
+from . import product, sale, web
 
 
 def register():
@@ -17,6 +15,7 @@ def register():
         web.Shop_Product,
         web.Shop_ProductCategory,
         web.User,
+        product.Template,
         product.Product,
         product.Category,
         sale.Sale,
@@ -26,3 +25,9 @@ def register():
         web.Shop_Attribute,
         product.Attribute,
         module='web_shop', type_='model', depends=['product_attribute'])
+    Pool.register(
+        product.Image,
+        module='web_shop', type_='model', depends=['product_image'])
+    Pool.register(
+        web.Shop_TaxRuleCountry,
+        module='web_shop', type_='model', depends=['account_tax_rule_country'])
